@@ -1,4 +1,8 @@
-use rustea::{crossterm::event::MouseEvent, App, Command, Message};
+use rustea::{
+    command::quit,
+    crossterm::event::{MouseEvent, MouseEventKind},
+    App, Command, Message,
+};
 
 struct Model {
     col: u16,
@@ -8,6 +12,9 @@ struct Model {
 impl App for Model {
     fn update(&mut self, msg: Message) -> Option<Command> {
         if let Ok(mouse_event) = msg.downcast::<MouseEvent>() {
+            if let MouseEventKind::Down(_) = mouse_event.kind {
+                return Some(Box::new(quit));
+            }
             self.col = mouse_event.column;
             self.row = mouse_event.row;
         }
@@ -16,12 +23,16 @@ impl App for Model {
     }
 
     fn view(&self) -> String {
-        format!("Clicked row: {}, col: {}", self.col, self.row)
+        format!(
+            "Click to terminate. Mouse row: {}, col: {}",
+            self.col, self.row
+        )
     }
 }
 
 fn main() {
     let model = Model { col: 0, row: 0 };
 
+    rustea::enable_mouse_capture().unwrap();
     rustea::run(model).unwrap();
 }
