@@ -4,16 +4,24 @@ use crossterm::event::{KeyCode, KeyEvent};
 ///
 /// It is very minimal and leaves all control of rendering to the user.
 /// You are able to access the buffer and caret pos, and render the caret however you please.
-#[derive(Debug, Default, Clone)]
 pub struct Input {
     buffer: String,
     pos: usize,
 }
 
+impl Default for Input {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl Input {
     /// Simple contructor. Starts with an empty buffer.
     pub fn new() -> Self {
-        Self::default()
+        Self {
+            buffer: String::new(),
+            pos: 0,
+        }
     }
 
     /// Recieves crossterm `KeyEvent`s and updates the buffer and caret position.
@@ -57,8 +65,6 @@ impl Input {
 
     /// Returns the current buffer.
     pub fn buffer(&self) -> String {
-        // return owned buffer so buffer can be read and cleared together
-        // renamed to clone to better represent what's happening
         self.buffer.clone()
     }
 
